<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

function lcproext_acfsupport_init() {

	// Register a new feature:
	LC_Extensions_Core::register_extension(
		array(
			'id' => 'acfsupport',
			'rank' => 10,
			'title' => 'ACF Support',
			'description' => 'Advanced Custom Fields integration',
			'details' => 'https://livecomposerplugin.com/#' //@todo: add the right link
		)
	);

	/**
	 * Then, check if this extension is active.
	 * Don't load any plugin data if the extension is disabled.
	 */
	if ( LC_Extensions_Core::is_extension_active( 'acfsupport' ) ) :

		if ( ! class_exists( 'LC_AcfIntegration' ) && class_exists( 'DSLC_Module' )  ) {

			if ( version_compare( DS_LIVE_COMPOSER_VER, '1.3', '>=' ) ) {

				/**
				 * Main LC_AcfIntegration Class.
				 */
				class LC_AcfIntegration {

					/**
					 * Instance var
					 *
					 * @var LC_AcfIntegration The one true LC_AcfIntegration
					 */
					private static $instance;

					/**
					 * Prevent creating multiple instances
					 */
					public function __construct() {

						$this->setup_constants();
						$this->includes();
						add_action( 'wp_enqueue_scripts', array( $this, 'load_styles' ) );
					}

					/**
					 * Setup plugin constants.
					 *
					 * @access private
					 * @return void
					 */
					private function setup_constants() {

						// Plugin version.
						if ( ! defined( 'LC_AcfIntegration_VERSION' ) ) {

							define( 'LC_AcfIntegration_VERSION', '1.0' );
						}

						// Plugin Folder Path.
						if ( ! defined( 'LC_AcfIntegration_PLUGIN_DIR' ) ) {

							define( 'LC_AcfIntegration_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
						}

						// Plugin Folder URL.
						if ( ! defined( 'LC_AcfIntegration_PLUGIN_URL' ) ) {

							define( 'LC_AcfIntegration_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
						}

						// Plugin Root File.
						if ( ! defined( 'LC_AcfIntegration_PLUGIN_FILE' ) ) {

							define( 'LC_AcfIntegration_PLUGIN_FILE', __FILE__ );
						}

						// Plugin Text Domain.
						if ( ! defined( 'LC_AcfIntegration_TEXTDOMAIN' ) ) {

							define( 'LC_AcfIntegration_TEXTDOMAIN', 'lc-acfintegration' );
						}
					}

					/**
					 * Include required files.
					 *
					 * @access private
					 * @return void
					 */
					private function includes() {

						require_once LC_AcfIntegration_PLUGIN_DIR . 'assets/display-functions.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/text/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/textarea/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/wysiwyg/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/number/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/page-link/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/date-picker/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/image/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/checkbox/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/select/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/file/module.php';
						require_once LC_AcfIntegration_PLUGIN_DIR . 'modules/taxonomy/module.php';
					}

					/**
					 * Load CSS styles on front end
					 *
					 * @access public
					 * @return void
					 */
					public function load_styles() {

						// Use minified libraries if SCRIPT_DEBUG is turned off.
						$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
						$css_dir = LC_AcfIntegration_PLUGIN_URL . 'assets/css/';

						wp_register_style( LC_AcfIntegration_TEXTDOMAIN . '-frontend-css', $css_dir . 'lc-acfintegration-extender' . $suffix . '.css', array(), LC_AcfIntegration_VERSION, 'all' );
						wp_enqueue_style( LC_AcfIntegration_TEXTDOMAIN . '-frontend-css' );
					}

				}

				$lc_acf = new LC_AcfIntegration;

			} else {

				/**
				 * Admin Notice
				 */
				function lcacf_notice_lc_version() {
				?>
				<div class="notice notice-error">
					<p><?php printf( __( 'The "Live Composer - ACF" add-on requires Live Composer version 1.3+. %sContact our support team%s if you need a previous version.', 'lc-acf-integration' ), '<a target="_blank" href="https://livecomposerplugin.com/support/">', '</a>' ); ?></p>
				</div>
				<?php }
				add_action( 'admin_notices', 'lcacf_notice_lc_version' );
			}
		} else {
			/**
			 * Admin Notice
			 */
			function lcacf_inactive_notice() {
			?>
			<div class="error">
				<p><?php printf( __( '%sCan\'t activate ACF extension for Live Composer.%s Both %sACF%s and %sLive Composer%s plugins should be active.', 'lc-acfintegration' ), '<strong>', '</strong>', '<a target="_blank" href="https://en-ca.wordpress.org/plugins/advanced-custom-fields/">', '</a>', '<a target="_blank" href="https://wordpress.org/plugins/live-composer-page-builder/">', '</a>' ); ?></p>
			</div>
			<?php }
			add_action( 'admin_notices', 'lcacf_inactive_notice' );
		}

	endif; // If is_extension_active.
}

lcproext_acfsupport_init();