<?php
/**
 *  Plugin Name: Live Composer - Premium Extensions
 *  Plugin URI: https://livecomposerplugin.com/downloads/extensions/?utm_source=lc-permium-extensions&utm_medium=wp-admin/plugins-list&utm_campaign=plugin_uri
 *  Description: Extend Live Composer with premium extensions
 *  Author: Live Composer Team
 *  Version: 0.1
 *  Author URI: https://livecomposerplugin.com/?utm_source=lc-menu-pro&utm_medium=wp-admin/plugins-list&utm_campaign=author_uri
 *  License: GPL3
 *  License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *  Domain Path: /lang
 *
 *  Live Composer - Premium Extensions Plugin is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Live Composer - Premium Extensions. If not, see <http://www.gnu.org/licenses/>.
 *
 *  @package Live Composer - Premium Extensions
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Run plugin only if the Live Composer plugin is loaded and active.
 */
function lcproext_plugin_init() {

	if ( class_exists( 'DSLC_Module' )  ) {
		// Start Plugin.
		$lcproext_core = new LC_Extensions_Core;

	} else {
		/**
		 * Admin Notice
		 */
		function lcproext_inactive_notice() {
		?>
		<div class="error">
			<p><?php printf( __( '%sCan\'t activate the Modules.%s %sLive Composer%s plugin should be active.', 'lcmenupro' ), '<strong>', '</strong>', '<a target="_blank" href="https://wordpress.org/plugins/live-composer-page-builder/">', '</a>' ); ?></p>
		</div>
		<?php }
		add_action( 'admin_notices', 'lcproext_inactive_notice' );

	} // End if class_exists check.

} add_action( 'plugins_loaded', 'lcproext_plugin_init' );


if ( ! class_exists( 'LC_Extensions_Core' ) ):

	/**
	 * Core Class
	 */
	class LC_Extensions_Core {

		/**
		 * Was this class ever instantiated?
		 *
		 * @var bool
		 */
		public static $initiated = false;

		/**
		 * Current version of the plugin.
		 *
		 * @var string
		 */
		private static $version;

		/**
		 * Define plugin slug based on the folder name.
		 *
		 * @var string
		 */
		private static $slug;

		/**
		 * Define plugin absolute path based.
		 *
		 * @var string
		 */
		private static $abspath;

		/**
		 * Define url to the plugin folder.
		 *
		 * @var string
		 */
		private static $dirurl;

		/**
		 * Array with information about each premium module.
		 *
		 * @var array
		 */
		private static $extensions;

		/**
		 * Define default extension status: active=true/inactive=false.
		 *
		 * @var bool
		 */
		private static $default_extension_status;


		/**
		 * EDD: Options id to store the license info.
		 *
		 * @var string
		 */
		private static $license_option_id = 'lc_extensions_licence';

		/**
		 * EDD: The name of the product in store.
		 * This is the title of the product in EDD and should match
		 * the download title in EDD exactly.
		 *
		 * @var string
		 */
		private static $product_name = 'Official Extensions Pack';


		/**
		 * EDD: The id of the product in store.
		 *
		 * @var string
		 */
		private static $product_id = 8138;

		/**
		 * EDD: Store URL.
		 * This is the URL our updater / license checker pings.
		 *
		 * @var string
		 */
		private static $store_url = 'https://livecomposerplugin.com';



		/**
		 * Do all the required job on core object creation.
		 */
		function __construct() {


			// error_log( 'LC_Extensions_Core > construct initiated:' );
			// error_log ( self::$initiated );
			// error_log ( '<< ?' );

			// Do nothing if LiveComposer is not activated.
			if ( ! class_exists( 'DSLC_Module', false ) ) {
				error_log ( 'Live Composer not loaded' );
				return;
			}

			// Actions that needs to be lunched only once.
			if ( ! self::$initiated ) {

				$this->set_abspath();
				$this->set_dirurl();
				$this->set_slug();
				$this->set_version();
				$this->load_plugin_data();

				self::$initiated = true;

				$this->require_files();
				$this->require_extensions();

				add_filter( 'dslc_extensions_meta', array( $this,'filter_lc_extensions' ) );
				add_action( 'dslc_toggle_extension', array( $this,'toggle_extension' ) );
				add_action( 'activated_plugin', array( $this,'detect_plugin_activation' ) );


				// Licence related calls.
				add_action( 'admin_init', array( $this, 'setup_plugin_updater' ), 0 );
				// add_action( 'dslc_extend_admin_panel_options', array( $this, 'lcmenupro_register_admin_settings_license' ) );
				// add_filter( 'dslc_filter_section_description', array( $this, 'lcmenupro_add_settings_description_license' ), 10, 2 );
				// add_action( 'admin_init', array( $this, 'lcmenupro_edd_register_option' ) );
				// add_action( 'admin_init', array( $this, 'lcmenupro_edd_activate_license' ) );
				// add_action( 'admin_notices', array( $this, 'lcmenupro_edd_admin_notices' ) );
				// add_action( 'admin_init', array( $this, 'lcmenupro_edd_deactivate_license' ) );
			}
		}


		/**
		 * Setup the updater.
		 */
		public function setup_plugin_updater() {

			// if ( false === get_option( self::$license_option_id ) ) {
				// Retrieve our license key from the DB.
				$license_key = trim( get_option( self::$license_option_id ) );

				// Setup the updater.
				$edd_updater = new LC_Extensions_Plugin_Updaters( self::$store_url, __FILE__, array(
						'version' 	=> self::$version, 	// Current version number.
						'license' 	=> $license_key, 	// License key (used get_option above to retrieve from DB).
						'item_id'   => self::$product_id, // Id of this plugin in EDD store.
						'author' 	=> 'Live Composer Team',// Author of this plugin.
						'url'       => home_url(),
					)
				);
			// }
		}










		/**
		 * Update $slug member variable with right value
		 * based on the current name of the plugin folder.
		 */
		public function set_slug() {
			$plugin_path_array = explode( '/', plugin_basename( __FILE__) );
			self::$slug = $plugin_path_array[0];
		}

		static public function get_slug() {
			return self::$slug;
		}

		public function set_dirurl() {
			self::$dirurl = plugin_dir_url( __FILE__ );
		}

		static function get_dirurl() {
			return self::$dirurl;
		}

		/**
		 * Update $abspath member variable with right value.
		 */
		public function set_abspath() {
			self::$abspath = __DIR__;
		}

		static function get_abspath() {
			return self::$abspath;
		}

		/**
		 * Update $version member variable with a right value.
		 */
		public function set_version() {
			// $version = get_file_data( self::$abspath . '/' . __FILE__ . '.php', array( 'Version' ), 'plugin' );
			$version = get_file_data( __FILE__, array( 'Version' ), 'plugin' );
			self::$version = $version[0];
		}

		/**
		 * Load saved data from the database.
		 * For now we are storing only extension status in the database.
		 *
		 * @return void
		 */
		public function load_plugin_data() {
			$plugin_data = get_option( 'lcextpro', false );

			if ( $plugin_data && isset( $plugin_data['extensions'] ) ) {
				$extensions_db = $plugin_data['extensions'];

				// Iterate through class $extensions property to update
				// extension status based on data saved in the database.
				foreach ( $extensions_db as $extension_id => $extension) {
					self::$extensions[ $extension_id ]['active'] = $extension['active'];
				}
			}
		}

		/**
		 * Save plugin data in the database.
		 *
		 * @return void
		 */
		public function save_plugin_data() {
			$plugin_data = get_option( 'lcextpro', false );

			// We are saving only extension id and status.
			foreach ( self::$extensions as $extension_id => $extension) {
				$plugin_data['extensions'][ $extension_id ][ 'active' ] = $extension['active'];
			}

			// $plugin_data['extensions'] = self::$extensions;

			update_option( 'lcextpro', $plugin_data );
		}

		/**
		 * Required actions on plugin bootstrap.
		 *
		 * @return void
		 */
		public function require_files() {

			// Load EDD custom updater.
			// if ( ! class_exists( 'EDD_LCMenuPro_Plugin_Updater' ) ) {
			require_once $this->get_abspath() . '/includes/plugin-updater.php';
			// }
		}

		/**
		 * Load extensions.
		 *
		 * @return void
		 */
		public function require_extensions() {
			$directories = glob( self::$abspath . '/extensions/*', GLOB_ONLYDIR );

			foreach ( $directories as $dir ) {
				$extensionpath = $dir . '/extension.php';
				if ( file_exists( $extensionpath ) ) {
					require_once $extensionpath;
				}
			}
		}

		/**
		 * Add meta about new extension
		 *
		 * @return void
		 */
		static public function register_extension( $meta ) {
			$id = '';
			$title = '';
			$thumbnail = '';
			$details = '';
			$description = '';
			$rank = 100; // 100 is the last / 0 is the first.
			$active = self::$default_extension_status; // Default extensions status.

			// Id or extensions slug.
			if ( isset( $meta['id'] ) ) {
				$id = $meta['id'];
			}

			// Extension title.
			if ( isset( $meta['title'] ) ) {
				$title = $meta['title'];
			}

			// Picture to use on extensions listing page.
			if ( isset( $meta['thumbnail'] ) ) {
				$thumbnail = $meta['thumbnail'];
			} else {
				$file = 'extensions/' . $id . '/thumbnail.png';
				$file_path = self::get_abspath() . '/' . $file;

				if ( file_exists ( $file_path ) ) {
					$thumbnail = self::get_dirurl() . $file; 
				} else {
					$thumbnail = false;
				}
			}

			// URL to the more infromation about the extension.
			if ( isset( $meta['details'] ) ) {
				$details = $meta['details'];
			}

			// A few lines with description about this extension.
			if ( isset( $meta['description'] ) ) {
				$description = $meta['description'];
			}

			// Check if self::$extensions is already have infromation regarding
			// status of this extension.
			if ( isset( self::$extensions[ $id ] ) && 
					isset( self::$extensions[ $id ]['active'] )  ) {
				$active = self::$extensions[ $id ]['active'];
			}

			// Rank used to sort the extensions on the listing page.
			if ( isset( $meta['rank'] ) ) {
				$rank = $meta['rank'];
			}

			// Register extension in the class attribute.
			self::$extensions[ $meta['id'] ] = array(
				'title' => $title, 
				'thumbnail' => $thumbnail,
				'details' => $details,
				'description' => $description,
				'active' => $active,
				'rank' => $rank,
			);
		}

		/**
		 * Get meta about all extensions
		 *
		 * @return array
		 */
		public function get_extensions() {
			return self::$extensions;
		}

		public function filter_lc_extensions( $extensions ) {

			$extensions = $this->get_extensions();
			return $extensions;

		}

		public function toggle_extension( $extension_id ) {

			error_log ( 'toggle_extension' );
			error_log ( $extension_id );

			foreach ( self::$extensions as $id => $value) {
				if ( $extension_id === $id ) {
					self::$extensions[$id]['active'] = ! self::$extensions[$id]['active'];
				}
			}

			// Make sure changed status is stored in the database.
			$this->save_plugin_data();
		}

		static public function is_extension_active( $extension_id ) {
			if ( isset( self::$extensions[ $extension_id ] ) && 
					isset( self::$extensions[ $extension_id ]['active'] ) ) {
				return self::$extensions[ $extension_id ]['active'];
			} else {
				return self::$default_extension_status;
			}
		}

		/**
		 * In some cases we need to disable our legacy plugins that
		 * are bundled now into this single set.
		 *
		 * @return void
		 */
		public function detect_plugin_activation( $plugin ) {
			// $plugin = akismet/akismet.php

			$old_plugin_slugs = array(
				// Google Maps
				'lc-googlemaps/lc-googlemaps.php',
				'sklc-addon-googlemaps/sklc-addon-googlemaps.php',
				// Gallery
				'lc-gallery/sklc-addon-gallery-images.php',
				'sklc-addon-gallery-images/sklc-addon-gallery-images.php',
				// Video
				'lc-video-embed/lc-video-embed.php',
				'lc-extension-video-embed/lc-video-embed.php',
				'lc-module-video-embed/lc-module-video-embed.php',
				// Animations
				'lc-addon-animations/lc-addon-animations.php',
				// Posts Links
				'sklc-addon-prev-next-post/sklc-addon-prev-next-post.php',
				// Per Content Width
				'sklc-per-page-content-width/sklc-per-page-content-width.php',
				// Before/After Image slider
				'sklc-before-after-image/sklc-before-after-image.php',
				// LineIcons
				'sklc-linecons-icons/sklc-linecons-icons.php',
				// Templates for CPT
				'lc-templatesforcpt/lc-templatesforcpt.php',
				// ACF integration
				'lc-acfintegration/lc-acfintegration.php',
				// Sliders integration
				'lc-sliders-integration/lc-masterslider.php',
				// Menu Pro
				'lc-menu-pro/lc-menu-pro.php',
			);

			// Deactivate the old version of plugin.
			foreach ( $old_plugin_slugs as $old_plugin ) {
				if ( is_plugin_active( $old_plugin ) ) {
					deactivate_plugins( $old_plugin );
				}
			}
		}
	}

endif; // if ( ! class_exists( 'LC_Extensions_Core' ) ).
